@@ -2,11 +2,12 @@ package Alien::Build::CommandSequence;
 
 use strict;
 use warnings;
+use 5.008004;
 use Text::ParseWords qw( shellwords );
 use Capture::Tiny qw( capture );
 
 # ABSTRACT: Alien::Build command sequence
-our $VERSION = '2.25'; # VERSION
+our $VERSION = '2.28'; # VERSION
 
 
 sub new
@@ -201,7 +202,7 @@ Alien::Build::CommandSequence - Alien::Build command sequence
 
 =head1 VERSION
 
-version 2.25
+version 2.28
 
 =head1 CONSTRUCTOR
 
@@ -277,6 +278,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
