@@ -2,12 +2,13 @@ package Alien::Build::Plugin::Build::MSYS;
 
 use strict;
 use warnings;
+use 5.008004;
 use Alien::Build::Plugin;
 use File::Which ();
 use Env qw( @PATH );
 
 # ABSTRACT: MSYS plugin for Alien::Build
-our $VERSION = '2.25'; # VERSION
+our $VERSION = '2.28'; # VERSION
 
 
 has msys_version   => '0.07';
@@ -80,7 +81,7 @@ Alien::Build::Plugin::Build::MSYS - MSYS plugin for Alien::Build
 
 =head1 VERSION
 
-version 2.25
+version 2.28
 
 =head1 SYNOPSIS
 
@@ -176,6 +177,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
