@@ -2,11 +2,12 @@ package Alien::Build::Plugin::Build::SearchDep;
 
 use strict;
 use warnings;
+use 5.008004;
 use Alien::Build::Plugin;
 use Text::ParseWords qw( shellwords );
 
 # ABSTRACT: Add dependencies to library and header search path
-our $VERSION = '2.25'; # VERSION
+our $VERSION = '2.28'; # VERSION
 
 
 has aliens => {};
@@ -133,7 +134,7 @@ Alien::Build::Plugin::Build::SearchDep - Add dependencies to library and header
 
 =head1 VERSION
 
-version 2.25
+version 2.28
 
 =head1 SYNOPSIS
 
@@ -221,6 +222,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
