@@ -2,6 +2,7 @@ package Alien::Build::Plugin::Core::Gather;
 
 use strict;
 use warnings;
+use 5.008004;
 use Alien::Build::Plugin;
 use Env qw( @PATH @PKG_CONFIG_PATH );
 use Path::Tiny ();
@@ -10,7 +11,7 @@ use Alien::Build::Util qw( _mirror _destdir_prefix );
 use JSON::PP ();
 
 # ABSTRACT: Core gather plugin
-our $VERSION = '2.26'; # VERSION
+our $VERSION = '2.28'; # VERSION
 
 
 sub init
@@ -153,7 +154,7 @@ Alien::Build::Plugin::Core::Gather - Core gather plugin
 
 =head1 VERSION
 
-version 2.26
+version 2.28
 
 =head1 SYNOPSIS
 
@@ -226,6 +227,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
