@@ -2,10 +2,11 @@ package Alien::Build::Plugin::Extract::ArchiveZip;
 
 use strict;
 use warnings;
+use 5.008004;
 use Alien::Build::Plugin;
 
 # ABSTRACT: Plugin to extract a tarball using Archive::Zip
-our $VERSION = '2.25'; # VERSION
+our $VERSION = '2.28'; # VERSION
 
 
 has '+format' => 'zip';
@@ -58,7 +59,7 @@ Alien::Build::Plugin::Extract::ArchiveZip - Plugin to extract a tarball using Ar
 
 =head1 VERSION
 
-version 2.25
+version 2.28
 
 =head1 SYNOPSIS
 
@@ -161,6 +162,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
