@@ -2,12 +2,13 @@ package Alien::Build::Plugin::Fetch::Local;
 
 use strict;
 use warnings;
+use 5.008004;
 use Alien::Build::Plugin;
 use File::chdir;
 use Path::Tiny ();
 
 # ABSTRACT: Plugin for fetching a local file
-our $VERSION = '2.25'; # VERSION
+our $VERSION = '2.28'; # VERSION
 
 
 has '+url' => '';
@@ -102,7 +103,7 @@ Alien::Build::Plugin::Fetch::Local - Plugin for fetching a local file
 
 =head1 VERSION
 
-version 2.25
+version 2.28
 
 =head1 SYNOPSIS
 
@@ -213,6 +214,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
