@@ -2,13 +2,14 @@ package Alien::Build::Temp;
 
 use strict;
 use warnings;
+use 5.008004;
 use Carp ();
 use Path::Tiny ();
 use File::Temp ();
 use File::Spec ();
 
 # ABSTRACT: Temp Dir support for Alien::Build
-our $VERSION = '2.26'; # VERSION
+our $VERSION = '2.28'; # VERSION
 
 
 # problem with vanilla File::Temp is that is often uses
@@ -82,7 +83,7 @@ Alien::Build::Temp - Temp Dir support for Alien::Build
 
 =head1 VERSION
 
-version 2.26
+version 2.28
 
 =head1 DESCRIPTION
 
@@ -146,6 +147,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
