@@ -2,9 +2,10 @@ package Alien::Build::rc;
 
 use strict;
 use warnings;
+use 5.008004;
 
 # ABSTRACT: Alien::Build local config
-our $VERSION = '2.26'; # VERSION
+our $VERSION = '2.28'; # VERSION
 
 
 sub logx ($)
@@ -39,7 +40,7 @@ Alien::Build::rc - Alien::Build local config
 
 =head1 VERSION
 
-version 2.26
+version 2.28
 
 =head1 SYNOPSIS
 
@@ -148,6 +149,8 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2020 by Graham Ollis.
